@@ -52,7 +52,7 @@ module Jekyll
 
         site.config["theme"] = theme.name
         site.theme = theme
-        site.theme.configure_sass
+        site.theme.configure_sass if site.theme.respond_to?(:configure_sass)
         site.send(:configure_include_paths)
         site.plugin_manager.require_theme_deps
       end
